Ganga
=====

Ganga is a tool to make it easy to run data analysis jobs along with managing associated data files.

.. toctree::
    :caption: For users
    :maxdepth: 2

    UserGuide/index
    GPI/index


Sections still to be added:

* Pure Python Usage
* Ganga as a Service
* Developing a New Application


.. toctree::
    :caption: For system administrators
    :maxdepth: 1

    sysadmin/index

.. toctree::
    :caption: For developers
    :maxdepth: 1

    dev/index
    API/index
